import { utils, BytesLike, BigNumberish, BaseContract, Signer, Overrides, ContractTransaction, CallOverrides, BigNumber, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface VRFConsumerBaseInterface extends utils.Interface {
    contractName: string | "VRFConsumerBase";
    functions: {
        "rawFulfillRandomness(bytes32,uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "rawFulfillRandomness", values: [BytesLike, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "rawFulfillRandomness", data: BytesLike): Result;
    events: {};
}
interface VRFConsumerBase extends BaseContract {
    contractName: string | "VRFConsumerBase";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: VRFConsumerBaseInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        rawFulfillRandomness(requestId: BytesLike, randomness: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    rawFulfillRandomness(requestId: BytesLike, randomness: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        rawFulfillRandomness(requestId: BytesLike, randomness: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {};
    estimateGas: {
        rawFulfillRandomness(requestId: BytesLike, randomness: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        rawFulfillRandomness(requestId: BytesLike, randomness: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}

export { VRFConsumerBase, VRFConsumerBaseInterface };
